@@ -104,7 +104,10 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
-        self._save_optimizer_redis()
+        if self.epoch > 0:
+            self._load_optimizer_redis()
+        else:
+            self._save_optimizer_redis()
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
         # self._load_optimizer_state()
